<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="48"/>
        <source>GME Plugin</source>
        <translation>Modul GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="51"/>
        <source>Game Music Files</source>
        <translation>Soubory s hudbou z her</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="114"/>
        <source>About GME Audio Plugin</source>
        <translation>O modulu GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="115"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Modul Qmmp GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="116"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Tento modul využívá knihovnu Game_Music_Emu pro přehrávání souborů s hudbou z her</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
